Unreleased Changes
------------------

0.6
===
* add UTM coordinates
* derive arca coordinates from UTM grid

0.5
---
* fix lat-lon mixup bug
* add convenience methods for coord trafo

0.4.0
-----
* move random sampling methods to `km3astro.random`

0.3.2
-----
* add example gallery

0.3.0 / 2017-03-18
------------------
* initial versioned release
* add package goodies
